==> medlogics-common-classes-1.6.0.jar: com/floreantpos/report/model/ExpenseReportDataModel.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.report.model;

import com.floreantpos.model.BalanceUpdateTransaction;
import com.floreantpos.model.util.DateUtil;
import com.floreantpos.swing.ListTableModel;
import com.floreantpos.util.NumberUtil;

public class ExpenseReportDataModel extends ListTableModel {

	public ExpenseReportDataModel() {
		setColumnNames(new String[] { "date", "manager", "recipient", "note", "amount", "eventDate" }); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$ //$NON-NLS-6$
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		BalanceUpdateTransaction data = (BalanceUpdateTransaction) rows.get(rowIndex);

		switch (columnIndex) {
			case 0:
				return DateUtil.formatReportDateWithBrowserTimeOffset(data.getTransactionTime());

			case 1:
				return data.getAccountManager();

			case 2:
				return data.getRecepientDisplay();

			case 3:
				return data.getDescription();

			case 4:
				return NumberUtil.getCurrencyFormatWithoutSymbol(data.getExpenseAmountDisplay());
				
			case 5:
				return data.getEventTimeDisplay();

		}
		return null;
	}

}

==> medlogics-common-classes-1.7.1.jar: com/floreantpos/report/model/ExpenseReportDataModel.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.report.model;

import com.floreantpos.model.BalanceUpdateTransaction;
import com.floreantpos.model.util.DateUtil;
import com.floreantpos.swing.ListTableModel;
import com.floreantpos.util.NumberUtil;

public class ExpenseReportDataModel extends ListTableModel {

	public ExpenseReportDataModel() {
		setColumnNames(new String[] { "date", "manager", "recipient", "note", "amount", "eventDate", "project", "category", "subcategory" }); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$ //$NON-NLS-6$ //$NON-NLS-7$ //$NON-NLS-8$ //$NON-NLS-9$
	}

	public Object getValueAt(int rowIndex, int columnIndex) {
		BalanceUpdateTransaction data = (BalanceUpdateTransaction) rows.get(rowIndex);

		switch (columnIndex) {
			case 0:
				return DateUtil.formatReportDateWithBrowserTimeOffset(data.getTransactionTime());

			case 1:
				return data.getAccountManager();

			case 2:
				return data.getRecepientDisplay();

			case 3:
				return data.getDescription();

			case 4:
				return NumberUtil.getCurrencyFormatWithoutSymbol(data.getExpenseAmountDisplay());

			case 5:
				return data.getEventTimeDisplay();

			case 6:
				return data.getProjectDisplay();

			case 7:
				return data.getReasonDisplay();

			case 8:
				return data.getSubCategoryDisplay();

		}
		return null;
	}

}
